@@ -85,7 +85,9 @@ class ProcfileWatcher(CircusPlugin):
                                               self.loop_rate * 1000,
                                               self.loop)
         self.circus_client = CircusClient()
-        self.cmds = {}
+
+    def get_cmd(self, name):
+        return self.call("get", name=name, keys=["cmd",])["cmd"]
 
     def envs(self):
         environs = {}
@@ -108,7 +110,6 @@ class ProcfileWatcher(CircusPlugin):
         pass
 
     def add_watcher(self, name, cmd):
-        self.cmds[name] = cmd
         env = {"port": self.port}
         env.update(self.envs())
         options = {
@@ -145,7 +146,7 @@ class ProcfileWatcher(CircusPlugin):
         to_change_names = cmds_names.intersection(new_cmds)
         to_change = {}
         for name in to_change_names:
-            if self.cmds.get(name) != procfile.commands.get(name):
+            if self.get_cmd(name) != procfile.commands.get(name):
                 to_change[name] = procfile.commands[name]
         return to_add, to_remove, to_change
 
