@@ -38,7 +38,6 @@ class ProcfileWatcherTest(TestCase):
         })
         plugin.add_watcher(name=name, cmd=cmd)
         plugin.circus_client.call.assert_called_with(options)
-        self.assertDictEqual({name: cmd}, plugin.cmds)
 
     def test_remove_watcher(self):
         plugin = ProcfileWatcher("", "", 1)
@@ -119,9 +118,22 @@ class ProcfileWatcherTest(TestCase):
         plugin = ProcfileWatcher("", "", 1)
         plugin.call = Mock()
         plugin.call.return_value = {"statuses": {"name": "name", "cmd": "cmd"}}
+        plugin.get_cmd = Mock()
+        plugin.get_cmd.return_value = "cmd"
         plugin.procfile_path = os.path.join(os.path.dirname(__file__),
                                             "testdata/Procfile3")
         plugin.look_after()
+        plugin.get_cmd.assert_called_with("name")
         plugin.call.assert_called_with("set",
                                        name="name",
                                        options={'cmd': 'cmd2'})
+
+    def test_get_cmd(self):
+        plugin = ProcfileWatcher("", "", 1)
+        plugin.call = Mock()
+        plugin.call.return_value = {"cmd": "ble"}
+        cmd = plugin.get_cmd("name")
+        self.assertEqual("ble", cmd)
+        plugin.call.assert_called_with("get",
+                                       name="name",
+                                       keys=["cmd",])
